Setup
=====

Requirements
------------

pypercolate runs under Python 2.7 and Python 3.4 (and later).
It requires the following Python packages:

.. include:: ../requirements.txt
   :literal:

Installation from PyPI
----------------------

To install the most recent stable version from the `Python Package Index
(PyPI)`_, including the dependencies, run

.. code:: bash

   $ pip install percolate

.. _Python Package Index (PyPI): https://pypi.python.org/pypi


Installation from source
------------------------

To install the latest version from the source repository, run

.. code:: bash

   $ pip install git+https://github.com/andsor/pypercolate.git

